@@ -19,10 +19,10 @@
 
 #include "category-button.h"
 #include "launcher-view.h"
+#include "util.h"
 
 #include <algorithm>
 
-#include <exo/exo.h>
 #include <glib/gi18n-lib.h>
 
 using namespace WhiskerMenu;
@@ -33,7 +33,8 @@ Category::Category(GarconMenu* menu) :
 	m_button(nullptr),
 	m_model(nullptr),
 	m_has_separators(false),
-	m_has_subcategories(false)
+	m_has_subcategories(false),
+	m_owns_button(true)
 {
 	const gchar* icon = nullptr;
 	const gchar* text = nullptr;
@@ -49,7 +50,7 @@ Category::Category(GarconMenu* menu) :
 	{
 		text = _("All Applications");
 	}
-	set_icon(!exo_str_is_empty(icon) ? icon : "applications-other", true);
+	set_icon(!xfce_str_is_empty(icon) ? icon : "applications-other");
 	set_text(text ? text : "");
 	set_tooltip(tooltip ? tooltip : "");
 }
@@ -60,7 +61,10 @@ Category::~Category()
 {
 	unset_model();
 
-	delete m_button;
+	if (m_owns_button)
+	{
+		delete m_button;
+	}
 
 	for (auto element : m_items)
 	{
@@ -130,6 +134,20 @@ void Category::append_separator()
 
 //-----------------------------------------------------------------------------
 
+void Category::set_button(CategoryButton* button)
+{
+	if (m_owns_button)
+	{
+		delete m_button;
+	}
+
+	m_owns_button = false;
+
+	m_button = button;
+}
+
+//-----------------------------------------------------------------------------
+
 void Category::sort()
 {
 	unset_model();
